@@ -36,10 +36,12 @@ char **argv;
 	int numsmpflg;
 	char prtfilename[32];
 	char hostname[9],comment[81];
+	char native[8];
 	short numsmp,smpint,numtrc;
 	short  numaux, cdpfold, origsmpint, orignumsmp;
 	int line_hdr_indx,trace_hdr_indx;
 	int indx,bytes,help,databytes,segydatabytes;
+	int native_line_header, native_trace_header, native_trace_data;
 	short samples;
 	char ntap[256],otap[256],map_file[256];
 	char *def_map_file;
@@ -92,13 +94,16 @@ char **argv;
 	help += C_ARGIS("-h",&argc,argv);
 	if (help > 0) {
 	  fprintf(stderr,"\nUsage: segy2usp -N[] -O[] -m mapping -M map_file");
-	  fprintf(stderr," -h -'?' -V level\n\n");
+	  fprintf(stderr,"\n\t-native [line | trace | data| all] -h -'?'");
+	  fprintf(stderr," -V level\n\n");
 	  fprintf(stderr,"       -N[input]   -- input SEGY data set (default=stdin)\n");
 	  fprintf(stderr,"       -O[output]  -- output USP data set (default=stdout)\n");
 	  fprintf(stderr,"       -map usp_header_mnemonic = segy_header_mnemonic|constant]\n");
 	  fprintf(stderr,"                   -- map header info\n");
 	  fprintf(stderr,"       -M          -- mapping file containing entries of form\n");
 	  fprintf(stderr,"                      usp_header_mnemonic = [segy_header_mnemonic|constant]\n");
+	  fprintf(stderr,"       -native [line | trace | data | all]\n");
+	  fprintf(stderr,"                   -- native format flags\n");
 	  fprintf(stderr,"       -V          -- verbose mode\n\n");
 	  fprintf(stderr,"       -h -?       -- display this help screen\n\n");
 	  exit(1);
@@ -201,6 +206,26 @@ char **argv;
 	  C_LBOPEN(&luout,otap,"w");
 	  }
 
+	native_line_header = 0;
+	native_trace_header = 0;
+        native_trace_data = 0;
+	for(i=0; i<3; i++) {
+	  C_ARGSTR("-native",native,"all"," ",&argc,argv);
+	  if (strcmp(native,"line") == 0) {
+	    native_line_header = 1;
+	    }
+	  if (strcmp(native,"trace") == 0) {
+	    native_trace_header = 1;
+	    }
+	  if (strcmp(native,"data") == 0) {
+	    native_trace_data = 1;
+	    }
+	  if (strcmp(native,"all") == 0) {
+	    native_line_header = 1;
+	    native_trace_header = 1;
+	    native_trace_data = 1;
+	    }
+	  }
 /*
 need to check return codes ; we should also realloc after looking up indices
 */
@@ -251,9 +276,11 @@ need to check return codes ; we should also realloc after looking up indices
 /* If necessary, we need to do byte rotations */
 
 #if ( BYTE_ORDER == LITTLE_ENDIAN )
-	HTOCL(buffer,3);
-	C_SAVELU("NumTrc",&format,&index,&length,SEGYLINEHEADER);
-	HTOCS(buffer+(index*sizeof(short)),25);
+	if (native_line_header != 1) {
+	  HTOCL(buffer,3);
+	  C_SAVELU("NumTrc",&format,&index,&length,SEGYLINEHEADER);
+	  HTOCS(buffer+(index*sizeof(short)),25);
+	  }
 #endif
 
 	get_hw_val(buffer, "JobNum", SEGYLINEHEADER, &jobnum);
@@ -761,17 +788,19 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 	  trcknt++;
 
 #if ( BYTE_ORDER == LITTLE_ENDIAN )
-	  HTOCL(buffer,7);
-	  C_SAVELU("TrcIdCode",&format,&index,&length,SEGYTRACEHEADER);
-	  HTOCS(buffer+(index*sizeof(short)),4);
-	  C_SAVELU("DstSgn",&format,&index,&length,SEGYTRACEHEADER);
-	  HTOCL(buffer+(index*sizeof(long)),8);
-	  C_SAVELU("ElevScaler",&format,&index,&length,SEGYTRACEHEADER);
-	  HTOCS(buffer+(index*sizeof(short)),2);
-	  C_SAVELU("SrcX",&format,&index,&length,SEGYTRACEHEADER);
-	  HTOCL(buffer+(index*sizeof(long)),4);
-	  C_SAVELU("XYUnits",&format,&index,&length,SEGYTRACEHEADER);
-	  HTOCS(buffer+(index*sizeof(short)),46);
+	  if (native_trace_header != 1) {
+	    HTOCL(buffer,7);
+	    C_SAVELU("TrcIdCode",&format,&index,&length,SEGYTRACEHEADER);
+	    HTOCS(buffer+(index*sizeof(short)),4);
+	    C_SAVELU("DstSgn",&format,&index,&length,SEGYTRACEHEADER);
+	    HTOCL(buffer+(index*sizeof(long)),8);
+	    C_SAVELU("ElevScaler",&format,&index,&length,SEGYTRACEHEADER);
+	    HTOCS(buffer+(index*sizeof(short)),2);
+	    C_SAVELU("SrcX",&format,&index,&length,SEGYTRACEHEADER);
+	    HTOCL(buffer+(index*sizeof(long)),4);
+	    C_SAVELU("XYUnits",&format,&index,&length,SEGYTRACEHEADER);
+	    HTOCS(buffer+(index*sizeof(short)),46);
+	    }
 #endif
 /*
    Take care of the specified trace header mappings
@@ -878,13 +907,14 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 
 	    switch(fmtcode) {
 		case(1):
-	    	  for (j=0; j<numsmp; j++) 
 /*
+	    	  for (j=0; j<numsmp; j++) 
 			ibmieee(buffer+SEGYTRACEHEADERBYTES+(j*sizeof(float)),
 			header+SZTRHD+(j*sizeof(float)));
 */
 #if ( BYTE_ORDER == LITTLE_ENDIAN )
-	  		HTOCL(buffer+SZTRHD,numsmp);
+		        if (native_trace_data != 1)
+	  		  HTOCL(buffer+SZTRHD,numsmp);
 			ibm_to_float(buffer+SEGYTRACEHEADERBYTES,
 				header+SZTRHD,numsmp,0);
 #else
@@ -899,7 +929,7 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 				(j*sizeof(short))));
 			}
 #if ( BYTE_ORDER == LITTLE_ENDIAN )
-		  HTOCL(header+SZTRHD,numsmp);
+		  if (native_trace_data != 1) HTOCL(header+SZTRHD,numsmp);
 #endif
 		  break;
 		case(2):
@@ -908,7 +938,7 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 			  (*(int *)(buffer+SEGYTRACEHEADERBYTES+
 				(j*sizeof(int))));
 #if ( BYTE_ORDER == LITTLE_ENDIAN )
-		  HTOCL(header+SZTRHD,numsmp);
+		  if (native_trace_data != 1) HTOCL(header+SZTRHD,numsmp);
 #endif
 		  break;
 		}
